@@ -4,7 +4,7 @@ use serde_json::Value;
 
 use crate::{
     registry::{MetaSchema, MetaSchemaRef, Registry},
-    types::{ParseError, ParseFromJSON, ParseResult, ToJSON, Type},
+    types::{ParseError, ParseFromJSON, ParseFromParameter, ParseResult, ToJSON, Type},
 };
 
 impl<T: Type, const LEN: usize> Type for [T; LEN] {
@@ -65,6 +65,34 @@ impl<T: ParseFromJSON, const LEN: usize> ParseFromJSON for [T; LEN] {
     }
 }
 
+impl<T: ParseFromParameter, const LEN: usize> ParseFromParameter for [T; LEN] {
+    fn parse_from_parameter(_value: &str) -> ParseResult<Self> {
+        unreachable!()
+    }
+
+    fn parse_from_parameters<I: IntoIterator<Item = A>, A: AsRef<str>>(
+        iter: I,
+    ) -> ParseResult<Self> {
+        let mut values = Vec::new();
+
+        for s in iter {
+            values.push(
+                T::parse_from_parameters(std::iter::once(s.as_ref()))
+                    .map_err(ParseError::propagate)?,
+            );
+        }
+
+        if values.len() != LEN {
+            return Err(ParseError::custom(format!(
+                "the length of the list must be `{}`.",
+                LEN
+            )));
+        }
+
+        Ok(values.try_into().ok().unwrap())
+    }
+}
+
 impl<T: ToJSON, const LEN: usize> ToJSON for [T; LEN] {
     fn to_json(&self) -> Value {
         let mut values = Vec::with_capacity(self.len());
